@@ -88,19 +88,19 @@ add_booklet_mst(db, bk1, test_id = 'ZwitserMaris', booklet_id = 'easy')
 add_booklet_mst(db, bk2, test_id = 'ZwitserMaris', booklet_id = 'hard')
 
 
-## ---- echo=FALSE, out.width=300,out.height=300, fig.width=5,fig.height=5------
+## ----echo=FALSE, out.width=300,out.height=300, fig.width=5,fig.height=5-------
 design_plot(db,vertex.size=70,vertex.size2=30, vertex.label.cex=1.5, edge.label.cex=1.5)
 
-## ---- eval=FALSE--------------------------------------------------------------
+## ----eval=FALSE---------------------------------------------------------------
 #  db = create_mst_project(":memory:")
 
-## ---- echo=FALSE--------------------------------------------------------------
+## ----echo=FALSE---------------------------------------------------------------
 scoring_rules %>% slice(1:8) %>% kable(caption='data.frame scoring_rules', row.names=FALSE)
 
-## ---- eval=FALSE--------------------------------------------------------------
+## ----eval=FALSE---------------------------------------------------------------
 #  add_scoring_rules_mst(db, scoring_rules)
 
-## ---- echo=FALSE--------------------------------------------------------------
+## ----echo=FALSE---------------------------------------------------------------
 design %>% slice(1:8) %>% kable(caption='data.frame design')
 
 ## -----------------------------------------------------------------------------
@@ -108,16 +108,16 @@ routing_rules = mst_rules(
   easy = Mod_1[0:5] --+ Mod_2, 
   hard = Mod_1[6:10] --+ Mod_3)
 
-## ---- eval=FALSE--------------------------------------------------------------
+## ----eval=FALSE---------------------------------------------------------------
 #  create_mst_test(db,
 #                  test_design = design,
 #                  routing_rules = routing_rules,
 #                  test_id = 'ZwitserMaris')
 
-## ---- echo=FALSE--------------------------------------------------------------
+## ----echo=FALSE---------------------------------------------------------------
 bk1[1:4,1:6] %>% mutate(item06='...') %>% kable(caption='example data in wide format (`bk1` below)', row.names=FALSE)
 
-## ---- eval=FALSE--------------------------------------------------------------
+## ----eval=FALSE---------------------------------------------------------------
 #  add_booklet_mst(db, bk1, test_id = 'ZwitserMaris', booklet_id = 'easy')
 #  add_booklet_mst(db, bk2, test_id = 'ZwitserMaris', booklet_id = 'hard')
 
@@ -127,16 +127,16 @@ fi = fit_inter_mst(db, test_id = 'ZwitserMaris', booklet_id = 'hard')
 plot(fi, item_id='item21')
 plot(fi, item_id='item45')
 
-## ---- results='hide'----------------------------------------------------------
+## ----results='hide'-----------------------------------------------------------
 f = fit_enorm_mst(db)
 
 coef(f)
 
-## ---- echo=FALSE--------------------------------------------------------------
+## ----echo=FALSE---------------------------------------------------------------
 coef(f) %>% slice(1:8) %>% kable(caption='some item parameters fit on multi stage data')
 
 
-## ---- echo=FALSE, message=FALSE, warning=FALSE,results='hide'-----------------
+## ----echo=FALSE, message=FALSE, warning=FALSE,results='hide'------------------
 ## add an arbitrary item property
 
 item_type = get_items_mst(db)
@@ -146,7 +146,7 @@ add_item_properties_mst(db, item_type)
 
 prof = profile_tables_mst(f, dbReadTable(db, 'items'), 'item_domain')
 
-## ---- echo=FALSE, fig.align="center", fig.height=3, fig.width=6, results='hide', message=FALSE, warning=FALSE----
+## ----echo=FALSE, fig.align="center", fig.height=3, fig.width=6, results='hide', message=FALSE, warning=FALSE----
 observed = dbGetQuery(db,
                       "SELECT booklet_id, 
                       person_id, item_domain, item_score 
@@ -173,19 +173,19 @@ ggplot(full_join(prof, prof_naive,
                  by=c('booklet_score','booklet_id','item_domain')) %>%
          full_join(observed_smooth, by=c('booklet_score','booklet_id','item_domain')),
        aes(x = booklet_score, y = expected_domain_score.x, colour = item_domain)) +
-  geom_line(size=0.3) + 
+  geom_line(linewidth=0.3) + 
   geom_point(aes(y=observed_score), size = 0.1) +
   facet_grid(booklet_id~.,scale='free_y') + 
-  geom_line(aes(y=expected_domain_score.y), linetype = 'dotted',size=0.4) +
+  geom_line(aes(y=expected_domain_score.y), linetype = 'dotted',linewidth=0.4) +
   theme(panel.background = element_blank()) +
   labs(y='domain score', x ='test score')
 
 
-## ---- results='hide'----------------------------------------------------------
+## ----results='hide'-----------------------------------------------------------
 abl = ability_tables(f, method='MLE')
 abl
 
-## ---- echo=FALSE--------------------------------------------------------------
+## ----echo=FALSE---------------------------------------------------------------
 abl %>% slice(1:10) %>% kable(caption='score transformation table (abl)')
 
 
@@ -196,14 +196,14 @@ abl %>% slice(1:10) %>% kable(caption='score transformation table (abl)')
 plot(density(theta),bty='n',main='true distribution of ability',xlab=expression(theta))
 
 
-## ---- echo = FALSE,fig.height=3, fig.width=7, results='hide'------------------
+## ----echo = FALSE,fig.height=3, fig.width=7, results='hide'-------------------
 
 # Correct cml with dexterMST
 delta.cml.mst = coef(f)$beta
 
 # ordinary cml with dexter
-long.data = gather(bk1, key='item_id', value='item_score', -.data$person_id) %>%
-  bind_rows(gather(bk2, key='item_id', value='item_score', -.data$person_id))
+long.data = pivot_longer(bk1, names_to='item_id', values_to='item_score', -'person_id') %>%
+  bind_rows(pivot_longer(bk2, names_to='item_id', values_to='item_score', -'person_id'))
 
 par.cml.lin = fit_enorm(long.data)
 delta.cml.lin = coef(par.cml.lin)$beta 
@@ -234,37 +234,37 @@ plot(delta, delta.mml+mean(delta) - mean(delta.mml),
      main="MML", ylab = "estimate",xlim=lim,ylim=lim)
 abline(0,1,lty=3)
 
-## ---- eval=FALSE--------------------------------------------------------------
-#  tia_tables(get_responses_mst(db))$testStats %>%
-#    select(booklet_id, meanP)
+## ----eval=FALSE---------------------------------------------------------------
+#  tia_tables(get_responses_mst(db))$booklets %>%
+#    select(booklet_id, mean_pvalue)
 
-## ---- echo=TRUE---------------------------------------------------------------
-tia_tables(get_responses_mst(db))$testStats %>%
-  select(booklet_id, meanP) %>%
+## ----echo=TRUE----------------------------------------------------------------
+tia_tables(get_responses_mst(db))$booklets %>%
+  select(booklet_id, mean_pvalue) %>%
   kable(caption='mean item correct')
 
 
-## ---- par=list(bty='l')-------------------------------------------------------
+## ----par=list(bty='l')--------------------------------------------------------
 rsp_data = get_responses_mst(db)
 pv = plausible_values(rsp_data, parms = f)
 
 plot(density(pv$PV1), main='plausible value distribution', xlab='pv')
 
-## ---- out.width=300,out.height=300, fig.width=5,fig.height=5------------------
+## ----out.width=300,out.height=300, fig.width=5,fig.height=5-------------------
 design_plot(db, item_id!="item21")
 
-## ---- echo=FALSE, eval=FALSE--------------------------------------------------
+## ----echo=FALSE, eval=FALSE---------------------------------------------------
 #  db = open_mst_project("/home/timo/Documents/statlib/bitbucket/acet_mst_2018_8001.db")
 #  dbExecute(db, "alter table tests add column routing text not null default 'all'")
 #  f = fit_enorm_mst(db, test_id=="RRA1")
 #  design_plot(db,test_id=="RRA1")
 
-## ---- eval=FALSE--------------------------------------------------------------
+## ----eval=FALSE---------------------------------------------------------------
 #  lin.test_design = data.frame(module_id='mod1', item_id=paste('item',1:30), item_positon = 1:30)
 #  lin.rules = mst_rules(lin.booklet = mod1)
 #  create_mst_test(db, lin.test_design, lin.rules, test_id = 'linear test')
 #  
 
-## ---- echo=FALSE--------------------------------------------------------------
+## ----echo=FALSE---------------------------------------------------------------
 close_mst_project(db)
 
